package ru.myitschool.work.api

import retrofit2.Response
import retrofit2.http.Body
import retrofit2.http.GET
import retrofit2.http.Header
import retrofit2.http.POST
import retrofit2.http.Path

interface ApiService {
    @GET("api/{login}/auth")
    suspend fun authenticate(
        @Path("login") login: String,
        @Header("Authorization") authorization: String
    ): Response<UserAuthResponse> // Изменяем на UserAuthResponse

    @GET("api/{login}/info")
    suspend fun getUserInfo(@Path("login") login: String): Response<Map<String, Any>>

    @POST("api/employee/toggleAccess")
    suspend fun toggleAccess(@Body request: ToggleAccessRequest): Response<Unit>

    // Метод для получения информации о сотруднике
    @GET("api/employee/{login}")
    suspend fun getEmployeeInfo(@Path("login") login: String): Response<EmployeeData>
}

// Модель данных для ответа аутентификации
data class UserAuthResponse(
    val role: String // Добавляем поле для роли
)

// Модель данных для информации о сотруднике
data class EmployeeData(
    val name: String,
    val position: String,
    val lastVisit: String
)

// Модель данных для запроса блокировки/разблокировки доступа
data class ToggleAccessRequest(
    val login: String,
    val action: String // "block" или "unblock"
)